aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/Lib
diff options
context:
space:
mode:
Diffstat (limited to 'Lib')
-rw-r--r--Lib/test/list_tests.py4
-rw-r--r--Lib/test/mapping_tests.py4
-rw-r--r--Lib/test/pythoninfo.py23
-rw-r--r--Lib/test/support/__init__.py4
-rw-r--r--Lib/test/test_compile.py12
-rw-r--r--Lib/test/test_dict.py4
-rw-r--r--Lib/test/test_dictviews.py4
-rw-r--r--Lib/test/test_exception_group.py4
8 files changed, 41 insertions, 18 deletions
diff --git a/Lib/test/list_tests.py b/Lib/test/list_tests.py
index b1ef332522d..d9ab21d4941 100644
--- a/Lib/test/list_tests.py
+++ b/Lib/test/list_tests.py
@@ -6,7 +6,7 @@ import sys
from functools import cmp_to_key
from test import seq_tests
-from test.support import ALWAYS_EQ, NEVER_EQ, C_RECURSION_LIMIT
+from test.support import ALWAYS_EQ, NEVER_EQ, Py_C_RECURSION_LIMIT
class CommonTest(seq_tests.CommonTest):
@@ -61,7 +61,7 @@ class CommonTest(seq_tests.CommonTest):
def test_repr_deep(self):
a = self.type2test([])
- for i in range(C_RECURSION_LIMIT + 1):
+ for i in range(Py_C_RECURSION_LIMIT + 1):
a = self.type2test([a])
self.assertRaises(RecursionError, repr, a)
diff --git a/Lib/test/mapping_tests.py b/Lib/test/mapping_tests.py
index 5492bbf86d1..b3e4192e65d 100644
--- a/Lib/test/mapping_tests.py
+++ b/Lib/test/mapping_tests.py
@@ -2,7 +2,7 @@
import unittest
import collections
import sys
-from test.support import C_RECURSION_LIMIT
+from test.support import Py_C_RECURSION_LIMIT
class BasicTestMappingProtocol(unittest.TestCase):
@@ -625,7 +625,7 @@ class TestHashMappingProtocol(TestMappingProtocol):
def test_repr_deep(self):
d = self._empty_mapping()
- for i in range(C_RECURSION_LIMIT + 1):
+ for i in range(Py_C_RECURSION_LIMIT + 1):
d0 = d
d = self._empty_mapping()
d[1] = d0
diff --git a/Lib/test/pythoninfo.py b/Lib/test/pythoninfo.py
index c6288334780..b25def78e42 100644
--- a/Lib/test/pythoninfo.py
+++ b/Lib/test/pythoninfo.py
@@ -666,12 +666,34 @@ def collect_decimal(info_add):
def collect_testcapi(info_add):
try:
+ import _testcapi
+ except ImportError:
+ return
+
+ for name in (
+ 'LONG_MAX', # always 32-bit on Windows, 64-bit on 64-bit Unix
+ 'PY_SSIZE_T_MAX',
+ 'Py_C_RECURSION_LIMIT',
+ 'SIZEOF_TIME_T', # 32-bit or 64-bit depending on the platform
+ 'SIZEOF_WCHAR_T', # 16-bit or 32-bit depending on the platform
+ ):
+ copy_attr(info_add, f'_testcapi.{name}', _testcapi, name)
+
+
+def collect_testinternalcapi(info_add):
+ try:
import _testinternalcapi
except ImportError:
return
call_func(info_add, 'pymem.allocator', _testinternalcapi, 'pymem_getallocatorsname')
+ for name in (
+ 'SIZEOF_PYGC_HEAD',
+ 'SIZEOF_PYOBJECT',
+ ):
+ copy_attr(info_add, f'_testinternalcapi.{name}', _testinternalcapi, name)
+
def collect_resource(info_add):
try:
@@ -907,6 +929,7 @@ def collect_info(info):
collect_sys,
collect_sysconfig,
collect_testcapi,
+ collect_testinternalcapi,
collect_time,
collect_tkinter,
collect_windows,
diff --git a/Lib/test/support/__init__.py b/Lib/test/support/__init__.py
index 38ad965e155..84b74ee2c29 100644
--- a/Lib/test/support/__init__.py
+++ b/Lib/test/support/__init__.py
@@ -60,7 +60,7 @@ __all__ = [
"run_with_tz", "PGO", "missing_compiler_executable",
"ALWAYS_EQ", "NEVER_EQ", "LARGEST", "SMALLEST",
"LOOPBACK_TIMEOUT", "INTERNET_TIMEOUT", "SHORT_TIMEOUT", "LONG_TIMEOUT",
- "Py_DEBUG", "EXCEEDS_RECURSION_LIMIT", "C_RECURSION_LIMIT",
+ "Py_DEBUG", "EXCEEDS_RECURSION_LIMIT", "Py_C_RECURSION_LIMIT",
"skip_on_s390x",
]
@@ -2531,7 +2531,7 @@ def adjust_int_max_str_digits(max_digits):
EXCEEDS_RECURSION_LIMIT = 5000
# The default C recursion limit (from Include/cpython/pystate.h).
-C_RECURSION_LIMIT = 1500
+Py_C_RECURSION_LIMIT = 1500
#Windows doesn't have os.uname() but it doesn't support s390x.
skip_on_s390x = unittest.skipIf(hasattr(os, 'uname') and os.uname().machine == 's390x',
diff --git a/Lib/test/test_dict.py b/Lib/test/test_dict.py
index eab64b4f910..620d0ca4f4c 100644
--- a/Lib/test/test_dict.py
+++ b/Lib/test/test_dict.py
@@ -8,7 +8,7 @@ import sys
import unittest
import weakref
from test import support
-from test.support import import_helper, C_RECURSION_LIMIT
+from test.support import import_helper, Py_C_RECURSION_LIMIT
class DictTest(unittest.TestCase):
@@ -596,7 +596,7 @@ class DictTest(unittest.TestCase):
def test_repr_deep(self):
d = {}
- for i in range(C_RECURSION_LIMIT + 1):
+ for i in range(Py_C_RECURSION_LIMIT + 1):
d = {1: d}
self.assertRaises(RecursionError, repr, d)
diff --git a/Lib/test/test_dictviews.py b/Lib/test/test_dictviews.py
index 2bd9d6eef8c..34918585513 100644
--- a/Lib/test/test_dictviews.py
+++ b/Lib/test/test_dictviews.py
@@ -3,7 +3,7 @@ import copy
import pickle
import sys
import unittest
-from test.support import C_RECURSION_LIMIT
+from test.support import Py_C_RECURSION_LIMIT
class DictSetTest(unittest.TestCase):
@@ -280,7 +280,7 @@ class DictSetTest(unittest.TestCase):
def test_deeply_nested_repr(self):
d = {}
- for i in range(C_RECURSION_LIMIT//2 + 100):
+ for i in range(Py_C_RECURSION_LIMIT//2 + 100):
d = {42: d.values()}
self.assertRaises(RecursionError, repr, d)
diff --git a/Lib/test/test_exception_group.py b/Lib/test/test_exception_group.py
index a02d54da35e..20122679223 100644
--- a/Lib/test/test_exception_group.py
+++ b/Lib/test/test_exception_group.py
@@ -1,7 +1,7 @@
import collections.abc
import types
import unittest
-from test.support import C_RECURSION_LIMIT
+from test.support import Py_C_RECURSION_LIMIT
class TestExceptionGroupTypeHierarchy(unittest.TestCase):
def test_exception_group_types(self):
@@ -460,7 +460,7 @@ class ExceptionGroupSplitTests(ExceptionGroupTestBase):
class DeepRecursionInSplitAndSubgroup(unittest.TestCase):
def make_deep_eg(self):
e = TypeError(1)
- for i in range(C_RECURSION_LIMIT + 1):
+ for i in range(Py_C_RECURSION_LIMIT + 1):
e = ExceptionGroup('eg', [e])
return e
diff --git a/Lib/test/test_compile.py b/Lib/test/test_compile.py
index de513daf825..28b2c4686bb 100644
--- a/Lib/test/test_compile.py
+++ b/Lib/test/test_compile.py
@@ -11,7 +11,7 @@ import textwrap
import warnings
from test import support
from test.support import (script_helper, requires_debug_ranges,
- requires_specialization, C_RECURSION_LIMIT)
+ requires_specialization, Py_C_RECURSION_LIMIT)
from test.support.os_helper import FakePath
class TestSpecifics(unittest.TestCase):
@@ -111,7 +111,7 @@ class TestSpecifics(unittest.TestCase):
@unittest.skipIf(support.is_wasi, "exhausts limited stack on WASI")
def test_extended_arg(self):
- repeat = int(C_RECURSION_LIMIT * 0.9)
+ repeat = int(Py_C_RECURSION_LIMIT * 0.9)
longexpr = 'x = x or ' + '-x' * repeat
g = {}
code = textwrap.dedent('''
@@ -557,12 +557,12 @@ class TestSpecifics(unittest.TestCase):
@support.cpython_only
@unittest.skipIf(support.is_wasi, "exhausts limited stack on WASI")
def test_compiler_recursion_limit(self):
# Expected limit is C_RECURSION_LIMIT * 2
# Duplicating the limit here is a little ugly.
# Perhaps it should be exposed somewhere...
- fail_depth = C_RECURSION_LIMIT * 2 + 1
- crash_depth = C_RECURSION_LIMIT * 100
- success_depth = int(C_RECURSION_LIMIT * 1.8)
+ fail_depth = Py_C_RECURSION_LIMIT * 2 + 1
+ crash_depth = Py_C_RECURSION_LIMIT * 100
+ success_depth = int(Py_C_RECURSION_LIMIT * 1.8)
def check_limit(prefix, repeated, mode="single"):
expect_ok = prefix + repeated * success_depth
@@ -557,12 +557,12 @@ class TestSpecifics(unittest.TestCase):
def test_compiler_recursion_limit(self):
- # Expected limit is C_RECURSION_LIMIT * 2
+ # Expected limit is Py_C_RECURSION_LIMIT * 2
# Duplicating the limit here is a little ugly.
# Perhaps it should be exposed somewhere...